summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/bookkeeping.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/emu/bookkeeping.h')
-rw-r--r--src/emu/bookkeeping.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/src/emu/bookkeeping.h b/src/emu/bookkeeping.h
index 760789fd536..038d924f12f 100644
--- a/src/emu/bookkeeping.h
+++ b/src/emu/bookkeeping.h
@@ -32,11 +32,14 @@ public:
bookkeeping_manager(running_machine &machine);
// ----- tickets -----
+ // increment the number of dispensed tickets
+ void increment_dispensed_tickets(int delta);
+
// return the number of tickets dispensed
int get_dispensed_tickets() const;
- // increment the number of dispensed tickets
- void increment_dispensed_tickets(int delta);
+ // reset the number of dispensed tickets
+ void reset_dispensed_tickets();
// ----- coin counters -----
// write to a particular coin counter (clocks on active high edge)
@@ -45,6 +48,9 @@ public:
// return the coin count for a given coin
int coin_counter_get_count(int num);
+ // reset the coin count for a given coin
+ void coin_counter_reset_count(int num);
+
// enable/disable coin lockout for a particular coin
void coin_lockout_w(int num, int on);
@@ -56,8 +62,9 @@ public:
// getters
running_machine &machine() const { return m_machine; }
+
private:
- void config_load(config_type cfg_type, util::xml::data_node const *parentnode);
+ void config_load(config_type cfg_type, config_level cfg_level, util::xml::data_node const *parentnode);
void config_save(config_type cfg_type, util::xml::data_node *parentnode);
// internal state